# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/proto/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/proto/processor.proto',
  package='grebble_flow.grpc.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'grebble_flow/grpc/proto/processor.proto\x12\x17grebble_flow.grpc.proto\"D\n\x0b\x46lowRequest\x12\x10\n\x08\x66lowName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x01(\t\"F\n\x0c\x46lowResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x12\n\nattributes\x18\x02 \x01(\t\x12\x11\n\tstreamEnd\x18\x03 \x01(\x08\x32g\n\tProcessor\x12Z\n\x07\x45xecute\x12$.grebble_flow.grpc.proto.FlowRequest\x1a%.grebble_flow.grpc.proto.FlowResponse\"\x00\x30\x01\x62\x06proto3'
)




_FLOWREQUEST = _descriptor.Descriptor(
  name='FlowRequest',
  full_name='grebble_flow.grpc.proto.FlowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowName', full_name='grebble_flow.grpc.proto.FlowRequest.flowName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowRequest.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowRequest.attributes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=136,
)


_FLOWRESPONSE = _descriptor.Descriptor(
  name='FlowResponse',
  full_name='grebble_flow.grpc.proto.FlowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowResponse.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowResponse.attributes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamEnd', full_name='grebble_flow.grpc.proto.FlowResponse.streamEnd', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=208,
)

DESCRIPTOR.message_types_by_name['FlowRequest'] = _FLOWREQUEST
DESCRIPTOR.message_types_by_name['FlowResponse'] = _FLOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowRequest = _reflection.GeneratedProtocolMessageType('FlowRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLOWREQUEST,
  '__module__' : 'grebble_flow.grpc.proto.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowRequest)
  })
_sym_db.RegisterMessage(FlowRequest)

FlowResponse = _reflection.GeneratedProtocolMessageType('FlowResponse', (_message.Message,), {
  'DESCRIPTOR' : _FLOWRESPONSE,
  '__module__' : 'grebble_flow.grpc.proto.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowResponse)
  })
_sym_db.RegisterMessage(FlowResponse)



_PROCESSOR = _descriptor.ServiceDescriptor(
  name='Processor',
  full_name='grebble_flow.grpc.proto.Processor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=210,
  serialized_end=313,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='grebble_flow.grpc.proto.Processor.Execute',
    index=0,
    containing_service=None,
    input_type=_FLOWREQUEST,
    output_type=_FLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSOR)

DESCRIPTOR.services_by_name['Processor'] = _PROCESSOR

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/proto/app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/proto/app.proto',
  package='grebble_flow.grpc.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!grebble_flow/grpc/proto/app.proto\x12\x17grebble_flow.grpc.proto\"\x10\n\x0e\x41ppInfoRequest\"6\n\rProcessorInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x61ttributeSchema\x18\x02 \x01(\t\"M\n\x0f\x41ppInfoResponse\x12:\n\nprocessors\x18\x01 \x03(\x0b\x32&.grebble_flow.grpc.proto.ProcessorInfo2e\n\x03\x41pp\x12^\n\x07\x41ppInfo\x12\'.grebble_flow.grpc.proto.AppInfoRequest\x1a(.grebble_flow.grpc.proto.AppInfoResponse\"\x00\x62\x06proto3'
)




_APPINFOREQUEST = _descriptor.Descriptor(
  name='AppInfoRequest',
  full_name='grebble_flow.grpc.proto.AppInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=78,
)


_PROCESSORINFO = _descriptor.Descriptor(
  name='ProcessorInfo',
  full_name='grebble_flow.grpc.proto.ProcessorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebble_flow.grpc.proto.ProcessorInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeSchema', full_name='grebble_flow.grpc.proto.ProcessorInfo.attributeSchema', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=134,
)


_APPINFORESPONSE = _descriptor.Descriptor(
  name='AppInfoResponse',
  full_name='grebble_flow.grpc.proto.AppInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebble_flow.grpc.proto.AppInfoResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=213,
)

_APPINFORESPONSE.fields_by_name['processors'].message_type = _PROCESSORINFO
DESCRIPTOR.message_types_by_name['AppInfoRequest'] = _APPINFOREQUEST
DESCRIPTOR.message_types_by_name['ProcessorInfo'] = _PROCESSORINFO
DESCRIPTOR.message_types_by_name['AppInfoResponse'] = _APPINFORESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppInfoRequest = _reflection.GeneratedProtocolMessageType('AppInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPINFOREQUEST,
  '__module__' : 'grebble_flow.grpc.proto.app_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.AppInfoRequest)
  })
_sym_db.RegisterMessage(AppInfoRequest)

ProcessorInfo = _reflection.GeneratedProtocolMessageType('ProcessorInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSORINFO,
  '__module__' : 'grebble_flow.grpc.proto.app_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.ProcessorInfo)
  })
_sym_db.RegisterMessage(ProcessorInfo)

AppInfoResponse = _reflection.GeneratedProtocolMessageType('AppInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPINFORESPONSE,
  '__module__' : 'grebble_flow.grpc.proto.app_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.AppInfoResponse)
  })
_sym_db.RegisterMessage(AppInfoResponse)



_APP = _descriptor.ServiceDescriptor(
  name='App',
  full_name='grebble_flow.grpc.proto.App',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=215,
  serialized_end=316,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppInfo',
    full_name='grebble_flow.grpc.proto.App.AppInfo',
    index=0,
    containing_service=None,
    input_type=_APPINFOREQUEST,
    output_type=_APPINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APP)

DESCRIPTOR.services_by_name['App'] = _APP

# @@protoc_insertion_point(module_scope)



from pathlib import Path

import pkg_resources


def install_proto():
    import grpc_tools.protoc

    cwd = Path(pkg_resources.resource_filename("grebble_flow", "")).parents[0]
    proto_include = pkg_resources.resource_filename("grebble_flow", "grpc/proto/")
    python_out = pkg_resources.resource_filename("grebble_flow", "grpc/base/")
    for file in ["processor.proto", "app.proto"]:
        grpc_tools.protoc.main(
            [
                "grpc_tools.protoc",
                f"--proto_path={cwd}",
                f"--python_out=./",
                f"--grpc_python_out=./",
                f"{proto_include}{file}",
            ]
        )



import json

from grebble_flow.managment.info import generate_package_info

from grebble_flow.grpc.proto import app_pb2_grpc, app_pb2


class AppService(app_pb2_grpc.AppServicer):
    def __init__(self, *args, **kwargs):
        pass

    def AppInfo(self, request, context):
        info = generate_package_info()

        result = app_pb2.AppInfoResponse()
        result.processors.extend(
            [app_pb2.ProcessorInfo(name=processor["name"], attributeSchema=json.dumps(processor["attributes_schema"])) for processor in info["processors"]]
        )
        return result



from dataclasses import dataclass

from grebble_flow.processors.base import BaseFlowProcessor, FlowResponse


@dataclass
class Attributes:
    name: str


class SimpleProcessor(BaseFlowProcessor):
    name = "simple-flow-base"
    attributes = Attributes

    def execute(self, content, attributes: Attributes, *args, **kwargs) -> FlowResponse:
        """
        :param attributes: Attributes description
        :param data: Default data description
        """

        for i in range(0, 100):
            yield FlowResponse(
                attributes={"attribute_1": "test"},
                content={"test": content, "a": attributes.name},
            )
